# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Snappy Ecosystem Tests
# Copyright (C) 2017 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

"""Snapcraft client helpers"""

import pexpect


# login credentials exported by shell environment
from snappy_ecosystem_tests.utils import storeconfig

LOGIN_EMAIL, LOGIN_PASSWORD = storeconfig.get_store_credentials()


class Snapcraft(object):
    """Contain Snapcraft specific functionality to use via command
    line interface"""
    def __init__(self):
        """Create new snapcraft instance."""
        self._login = False
        self._cleanup()

    def _cleanup(self):
        """Perform cleanup actions"""
        self.logout()

    def logout(self):
        """logout of snapcraft store session"""
        child = pexpect.spawn("snapcraft logout")
        err = child.expect('Credentials cleared.')
        child.terminate(True)
        child.wait()
        if err is not 0:
            raise ValueError("Failed to logout")

        self._login = False

    def login(self):
        """login to store using the credential environment variables"""
        child = pexpect.spawn("snapcraft login")
        child.expect('Email: ')
        child.sendline(LOGIN_EMAIL)
        child.expect('Password:')
        child.sendline(LOGIN_PASSWORD)
        err = child.expect('Login successful')
        if err is not 0:
            raise ValueError("Failed to login")

        self._login = True

    def list_registered(self):
        """call snapcraft list-registered command,
        raise exception if not logged in"""
        if self._login is False:
            raise ValueError("User is not logged in, "
                             "please login before using this command")
        return pexpect.spawnu("snapcraft list-registered").read()
